cmoncrawl.aggregator.index\_query.IndexAggregator.aclose
========================================================

.. currentmodule:: cmoncrawl.aggregator.index_query

.. automethod:: IndexAggregator.aclose